% OddsRatio() and InvertOddsRatio() are functions for computing the 
% odds ratio phi=p/(1-p) from p, and for inverting
% this computation.  p is in [0,1], and phi is in [0,Inf].  
% We have functions so that they handle infinity correctly and without
% warnings.  So for any p in this range, we have 
% p==InvertOddsRatio(OddsRatio(p));
%
% This function works both for scalar and vector p.
function phi=OddsRatio(p)
    phi(find(p == 1)) = Inf;
    not_one = find(p ~= 1);
    phi(not_one) = p(not_one)./(1-p(not_one));
end
