function [phi, p] = SimulateSamplePath(window_lb, window_ub, q0, q1, Pdead)
    % General pre-computing
    T = length(window_lb)-1;
    phi_ub = OddsRatio(window_ub); % Convert probabilities to odds ratios.
    phi_lb = OddsRatio(window_lb);
    LikelihoodRatio1 = q1/q0;
    LikelihoodRatio0 = (1-q1)/(1-q0);

    % Generate a random deadline according to the cdf Pdead.
    D = min(find(Pdead >= rand)) - 1;
    phi(1) = 1; % Corresponds to p=1/2, as hardcoded on the next line.

    % Generate a true hypothesis
    theta = rand < 1/2; % Theta is a Bernoulli random variable.
    if (theta==1)
	probObserve1 = q1; % Probability of observing a 1.
    else % theta==0
        probObserve1 = q0;
    end

    % Loop until we hit the deadline or exit the window
    for t=0:D
    	tm = t+1;
	% Stop if we exit the window
	if (phi(tm) <= phi_lb(tm) || phi(tm)>=phi_ub(tm))
		break;
    	end

	% Our observation is a 0 or 1, and the probability
	% distribution depends upon theta. We compute the likelihood
	% ratio between the two hypotheses based upon the observation
	% above in the initial part of the function, then multiply it
	% by the old odds ratio to get the new odds ratio.
	x = rand < probObserve1;
	if (x==1)
		phi(tm+1) = LikelihoodRatio1 * phi(tm);
	else % x==0
		phi(tm+1) = LikelihoodRatio0 * phi(tm);
	end
    end
    p = InvertOddsRatio(phi);
end
